@@ -6,7 +6,7 @@ from dynamic_preferences.users.forms import user_preference_form_builder
 
 @login_required
 def index(request):
-    PreferencesForm = user_preference_form_builder(instance=request.user)
+    PreferencesForm = user_preference_form_builder(instance=request.user.user)
     if request.method == 'POST':
         form = PreferencesForm(request.POST)
         if form.is_valid():
@@ -19,6 +19,6 @@ def index(request):
         else:
             # TODO: check, if form reflects invalid
             #       payload for PreferencesForm
-            PreferencesForm = user_preference_form_builder(instance=request.user)
+            PreferencesForm = user_preference_form_builder(instance=request.user.user)
 
     return render(request, 'magplan/preferences/index.html', {'form': PreferencesForm})
